<?php
/**
 * @package CleverOgre
 * @subpackage WP-Live Chat by 3CX - Multisite Support Server
 * @since WP-Live Chat by 3CX - Multisite Support Server 0.2.0
 */

namespace MultisiteChatServer;

class Api {

    public static function check_online($site, $debug = false) {
        if ($site === false || !is_string($site) || empty($site)) return false;

        $parse = parse_url($site);

        $result = false;
        try {
            $ch = curl_init();

            curl_setopt($ch, CURLOPT_URL, "{$parse['scheme']}://{$parse['host']}/" . \MultisiteChatServer\Config::get_endpoint() . "?");
            curl_setopt($ch, CURLOPT_POSTFIELDS, http_build_query(array(
                'action' => \MultisiteChatServer\Config::get_action(),
            )));
            curl_setopt($ch, CURLOPT_POST, 1);
            curl_setopt($ch, CURLOPT_HEADER, 0); // $debug == true ? 1 : 0);
            curl_setopt($ch, CURLOPT_FOLLOWLOCATION, 0);
            curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, $parse['scheme'] == 'https' ? 1 : 0);
            curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, $parse['scheme'] == 'https' ? 1 : 0);
            curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
            curl_setopt($ch, CURLOPT_USERAGENT, $_SERVER['HTTP_USER_AGENT']);
            if ($debug == true) {
                curl_setopt($ch, CURLOPT_VERBOSE, 1);
                $verbose = fopen('php://temp', 'w+');
                curl_setopt($ch, CURLOPT_STDERR, $verbose);
            }

            $result = curl_exec($ch);

            if ($debug == true) {
                var_dump($result);
                if ($result === false && curl_errno($ch) != 0) {
                    printf("cUrl error (#%d): %s<br>\n", curl_errno($ch), esc_html(curl_error($ch)));
                }
                rewind($verbose);
                $verboseLog = stream_get_contents($verbose);
                echo "Verbose information:\n{$verboseLog}\n";
            }

            if ($result === false) {
                throw new Exception(curl_error($ch), curl_errno($ch));
            }

            curl_close($ch);
        } catch (Exception $e) {
            trigger_error(sprintf('Curl failed with error #%d: %s', $e->getCode(), $e->getMessage()), E_USER_ERROR);
        }

        if ($result === false || !is_string($result) || empty($result)) return false;

        $result = json_decode($result, $options = JSON_OBJECT_AS_ARRAY);
        return is_array($result) && !empty($result) && isset($result['success']) && $result['success'] == true && isset($result['data']) && isset($result['data']['found']) && $result['data']['found'] == '1';
    }

    private static function send_json($response, $status_code = null) {
        @header('Content-Type: application/json; charset=utf-8');
        if (null !== $status_code) status_header($status_code);

        echo json_encode($response);
        die;
    }

    public static function send_json_success($data = null, $status_code = null) {
        $response = array('success' => true);

        if (isset($data)) $response['data'] = $data;

        self::send_json($response, $status_code);
    }

    public static function send_json_error($data) {
        $response = array('success' => false);

        if (isset($data)) $response['data'] = $data;

        self::send_json($response, $status_code);
    }

}
