<?php
/**
 * @package CleverOgre
 * @subpackage WP-Live Chat by 3CX - Multisite Support Server
 * @since WP-Live Chat by 3CX - Multisite Support Server 0.2.0
 */

namespace MultisiteChatServer;

class Config {

    private static $config = false;

    private static function read_config() {
        if (self::$config === false) self::$config = parse_ini_file('config.ini', true);
        return self::$config;
    }

    private static function get_field($section, $key) {
        self::read_config();

        return is_array(self::$config) && isset(self::$config[$section]) && isset(self::$config[$section][$key]) ? self::$config[$section][$key] : null;
    }

    private static function get_section($section) {
        self::read_config();

        return is_array(self::$config) && isset(self::$config[$section]) && is_array(self::$config[$section]) ? self::$config[$section] : null;
    }

    // API settings
    public static function get_endpoint() {
        return self::get_field('api', 'endpoint');
    }
    public static function get_action() {
        return self::get_field('api', 'action');
    }
    public static function debug_enabled() {
        return intval(self::get_field('api', 'debug')) === 1;
    }
    public static function php_debug_enabled() {
        return intval(self::get_field('api', 'debug_php')) === 1;
    }
    public static function get_authorized_ips() {
        $ips = self::get_field('api', 'authorized_ips');
        return is_array($ips) && !empty($ips) ? $ips : array();
    }

    // Sites
    public static function get_sites() {
        $titles = self::get_field('sites', 'titles');
        $urls = self::get_field('sites', 'urls');
        if (!is_array($titles) || empty($titles) || !is_array($urls) || empty($urls)) return false;

        $sites = array();
        for ($i = 0; $i < max(count($titles), count($urls)); $i++) {
            $sites[$i] = array(
                'title' => $titles[$i],
                'url' => $urls[$i],
            );
        }

        return $sites;
    }

    // Company Info
    public static function get_info() {
        return self::get_section('info');
    }

}
